| Title: | The Unit-Garima Distribution |
|---|---|
| Description: | Density, distribution function, quantile function, and random generating function of the Unit-Garima distribution based on Ayuyuen, S., & Bodhisuwan, W. (2024)<doi:10.18187/pjsor.v20i1.4307>. |
| Authors: | Atchanut Rattanalertnusorn [aut, cre], Sirinapa Ayuyuen [aut], Winai Bodhisuwan [aut] |
| Maintainer: | Atchanut Rattanalertnusorn <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-22 05:43:06 UTC |
| Source: | https://github.com/cran/UGarima |
To show the pdf (or the cdf) of UGa distribution by specified parameter theta.
plotpdfUGa(x, theta) plotcdfUGa(x, theta)plotpdfUGa(x, theta) plotcdfUGa(x, theta)
x |
vector of quantile. |
theta |
shape parameter, where |
No return value, called for side effects
# library(lamW) is required for rUGa() function x <- rUGa(101,theta=1.5) x plotpdfUGa(x,theta = 1.5) plotcdfUGa(x,theta = 1.5)# library(lamW) is required for rUGa() function x <- rUGa(101,theta=1.5) x plotpdfUGa(x,theta = 1.5) plotcdfUGa(x,theta = 1.5)
Density, distribution function, quantile function, and random generation function
for UGa distribution with one parameter (theta). See details in references.
dUGa(x, theta, log = FALSE) pUGa(q, theta, lower.tail = TRUE, log.p = FALSE) qUGa(p, theta = 0.5) rUGa(n, theta)dUGa(x, theta, log = FALSE) pUGa(q, theta, lower.tail = TRUE, log.p = FALSE) qUGa(p, theta = 0.5) rUGa(n, theta)
x, q
|
vector of quantile. |
theta |
shape parameter, where |
log, log.p
|
logical; (default = |
lower.tail |
logical; if |
p |
vector of probabilities. |
n |
number of observations. |
dUGa gives the density,
pUGa gives the distribution function,
qUGa gives the quantile function,
and rUGa generates random samples.
Ayuyuen, S., & Bodhisuwan, W. (2024). A generating family of unit-Garima distribution: Properties, likelihood inference, and application. Pakistan Journal of Statistics and Operation Research, 20(1), 69-84. doi:10.18187/pjsor.v20i1.4307.
NULL x <- seq(0.1,1,by=0.1) dUGa(x,theta=0.5) #f(x) dUGa(x,theta=0.5,log=TRUE) #log(f(x)) pUGa(x,theta=1.5) #P(X<x) pUGa(x,theta=1.5,lower.tail = FALSE ) #P(X>x) # library(lamW) is required for qUGa() function x <- seq(0.1,1,by=0.1) x p <- pUGa(x,theta=2.5) p require(lamW) q <- qUGa(p,theta=2.5) q # q equal to x # library(lamW) is required for rUGa() function require(lamW) x <- rUGa(100,theta=1) x # 0<x<1, for all xNULL x <- seq(0.1,1,by=0.1) dUGa(x,theta=0.5) #f(x) dUGa(x,theta=0.5,log=TRUE) #log(f(x)) pUGa(x,theta=1.5) #P(X<x) pUGa(x,theta=1.5,lower.tail = FALSE ) #P(X>x) # library(lamW) is required for qUGa() function x <- seq(0.1,1,by=0.1) x p <- pUGa(x,theta=2.5) p require(lamW) q <- qUGa(p,theta=2.5) q # q equal to x # library(lamW) is required for rUGa() function require(lamW) x <- rUGa(100,theta=1) x # 0<x<1, for all x